body {
    font-family: "Microsoft YaHei UI";
    font-weight: bold;
    font-size: 17px;
    line-height: 22px;
}

.text {
    margin-top: 5px;
    word-break: break-all;
    white-space: pre-wrap;
    
}

.main-box {
    padding: 5px;
}